@@ -182,7 +182,11 @@ def test_write_cache_file():
 def test_update_sources_list():
     from rosdep2.sources_list import update_sources_list, InvalidData, compute_filename_hash, PICKLE_CACHE_EXT
     import cPickle
+    from urllib import pathname2url
     sources_list_dir=get_test_dir()
+    index_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'rosdistro', 'index.yaml'))
+    index_url = 'file://' + pathname2url(index_path)
+    os.environ['ROSDISTRO_INDEX_URL'] = index_url
     tempdir = tempfile.mkdtemp()
     # use a subdirectory of test dir to make sure rosdep creates the necessary substructure
     tempdir = os.path.join(tempdir, 'newdir')
@@ -213,10 +217,10 @@ def test_update_sources_list():
     # download data is present.
     with open(os.path.join(tempdir, 'index'), 'r') as f:
         index = f.read().strip()
-    expected = """#autogenerated by rosdep, do not edit. use 'rosdep update' instead
-yaml %s 
-yaml %s python
-yaml %s ubuntu"""%(GITHUB_URL, GITHUB_PYTHON_URL, BADHOSTNAME_URL)
+    expected = "#autogenerated by rosdep, do not edit. use 'rosdep update' instead\n"\
+               "yaml %s \n"\
+               "yaml %s python\n"\
+               "yaml %s ubuntu"%(GITHUB_URL, GITHUB_PYTHON_URL, BADHOSTNAME_URL)
     assert expected == index, "\n[%s]\nvs\n[%s]"%(expected, index)
 
 def test_load_cached_sources_list():
